#ifndef __PFE_PFE_BASE_H
#define __PFE_PFE_BASE_H "%full_filespec: pfe-base.h~bln_mpt1!33.7:incl:bln_12xx!1 %"

/** 
 * -- declare prototypes of the base system
 * 
 *  Copyright (C) Tektronix, Inc. 1998 - 2003. All rights reserved.
 *
 *  @see     GNU LGPL
 *  @author  Tektronix CTE             @(#) %derived_by: guidod %
 *  @version %version: bln_mpt1!33.7 %
 *    (%date_modified: Wed Apr 03 11:09:57 2002 %)
 *  @description
 *            most of the routines of the internal forth system
 *            are declared here
 */
/*@{*/

#include <pfe/pfe-ext.h>

#include <pfe/core-sub.h>
#include <pfe/core-ext.h>
#include <pfe/core-mix.h>
#include <pfe/dict-sub.h>
#include <pfe/dict-comp.h>
#include <pfe/header-sub.h>
#include <pfe/block-sub.h>
#include <pfe/block-ext.h>
#include <pfe/utils-sub.h>
#include <pfe/engine-sub.h>
#include <pfe/engine-set.h>
#include <pfe/exception-sub.h>
#include <pfe/memory-sub.h>
#include <pfe/misc-ext.h>
#include <pfe/option-ext.h>
#include <pfe/option-set.h>
#include <pfe/search-order-ext.h>
#include <pfe/signals-ext.h>
#include <pfe/tools-sub.h>
#include <pfe/tools-mix.h>

/*@}*/
#endif
